Package: spkTools
Version: 1.67.0
Date: 2016-02-10
Title: Methods for Spike-in Arrays
Author: Matthew N McCall <mccallm@gmail.com>, Rafael A Irizarry
        <rafa@jhu.edu>
Maintainer: Matthew N McCall <mccallm@gmail.com>
Depends: R (>= 2.7.0), Biobase (>= 2.5.5)
Suggests: xtable
Imports: Biobase (>= 2.5.5), graphics, grDevices, gtools, methods,
        RColorBrewer, stats, utils
Description: The package contains functions that can be used to compare
        expression measures on different array platforms.
License: GPL (>= 2)
URL: http://bioconductor.org
biocViews: Software, Technology, Microarray
git_url: https://git.bioconductor.org/packages/spkTools
git_branch: devel
git_last_commit: ff503f5
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: no
Packaged: 2025-10-30 23:13:17 UTC; biocbuild
